@@ -1,5 +1,6 @@
 '''Mark This database utility module.'''
 import json
+from functools import lru_cache
 from mt_aws_utils.dbutil import Db
 
 
@@ -16,6 +17,7 @@ class AWSMarkThis(Db):
 
         return self.singlequery(qry, (style, json.dumps(positions)))
 
+    @lru_cache(maxsize=40)
     def style_get(self, style):
         '''gets question positions for style.  Returns dict {qno: Rect}'''
         qry = 'SELECT positions FROM style WHERE style=%s'
@@ -40,6 +42,7 @@ class AWSMarkThis(Db):
 
         return self.executemany(qry, rows)
 
+    @lru_cache(maxsize=100)
     def sheet_get(self, sheetid):
         '''gets sheet info for sheetid'''
         qry = 'SELECT * FROM sheet WHERE sheetid=%s'
@@ -93,7 +96,6 @@ class AWSMarkThis(Db):
 
         return None
 
-
     def stack_insert(self, stack):
         '''Insert stack'''
 
